@@ -12,6 +12,8 @@
 #'  will be in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of all-time maxima is written.
 #'@export
@@ -55,6 +57,6 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_timmax.nc")))
-timmax <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
-  timx_wrapper("max", var, infile, outfile, nc34, overwrite, verbose = verbose)
+timmax <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE, nc = NULL) {
+  timx_wrapper("max", var, infile, outfile, nc34, overwrite, verbose = verbose, nc = nc)
 }
