@@ -67,7 +67,7 @@ test_that("attributes are correct", {
   expect_equal(actual, -999)
 
   actual <- ncatt_get(file, "SIS", "cmsaf_info")$value
-  expect_equal(actual, "cmsaf::cmsaf.divc SIS divided by 4")
+  expect_equal(actual, "cmsafops::cmsaf.divc SIS divided by 4")
 
   global_attr <- ncatt_get(file, 0)
   expect_equal(length(global_attr), 1)
